Commit-ID:  4ecf7191fdcc5686c1eb2b06d7f93ce29d636cf0
Gitweb:     http://git.kernel.org/tip/4ecf7191fdcc5686c1eb2b06d7f93ce29d636cf0
Author:     Stefan Assmann <sassm...@kpanic.de>
AuthorDate: Mon, 24 Jul 2017 14:22:48 +0200
Committer:  Ingo Molnar <mi...@kernel.org>
CommitDate: Tue, 25 Jul 2017 11:30:45 +0200

x86/efi: Fix reboot_mode when EFI runtime services are disabled

When EFI runtime services are disabled, for example by the "noefi"
kernel cmdline parameter, the reboot_type could still be set to
BOOT_EFI causing reboot to fail.

Fix this by checking if EFI runtime services are enabled.

Signed-off-by: Stefan Assmann <sassm...@kpanic.de>
Cc: Linus Torvalds <torva...@linux-foundation.org>
Cc: Peter Zijlstra <pet...@infradead.org>
Cc: Thomas Gleixner <t...@linutronix.de>
Link: http://lkml.kernel.org/r/20170724122248.24006-1-sassm...@kpanic.de
[ Fixed 'not disabled' double negation. ]
Signed-off-by: Ingo Molnar <mi...@kernel.org>
---
 arch/x86/kernel/reboot.c | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/arch/x86/kernel/reboot.c b/arch/x86/kernel/reboot.c
index 67393fc..a56bf60 100644
--- a/arch/x86/kernel/reboot.c
+++ b/arch/x86/kernel/reboot.c
@@ -471,12 +471,12 @@ static int __init reboot_init(void)
 
        /*
         * The DMI quirks table takes precedence. If no quirks entry
         * matches and the ACPI Hardware Reduced bit is set, force EFI
         * reboot.
         */
        rv = dmi_check_system(reboot_dmi_table);
 
-       if (!rv && efi_reboot_required())
+       if (!rv && efi_reboot_required() && !efi_runtime_disabled())
                reboot_type = BOOT_EFI;
 
        return 0;
@@ -471,12 +471,12 @@ static int __init reboot_init(void)
        /*
         * The DMI quirks table takes precedence. If no quirks entry
-        * matches and the ACPI Hardware Reduced bit is set, force EFI
-        * reboot.
+        * matches and the ACPI Hardware Reduced bit is set and EFI
+        * runtime services are enabled, force EFI reboot.
         */
        rv = dmi_check_system(reboot_dmi_table);

Reply via email to